@@ -1,4 +1,3 @@
-# from turtle import title
 import pandas as pd
 import numpy as np
 import matplotlib.pyplot as plt
@@ -137,6 +136,9 @@ def confusion(df, rvar, lev, pred, cost=1, margin=2):
         Proportion of cases to act on based on the cost/margin ratio
     """
 
+    if isinstance(pred, list) and len(pred) > 1:
+        return "This function can only take one predictor variables at time"
+
     break_even = cost / margin
     gtbe = df[pred] > break_even
     pos = df[rvar] == lev
@@ -389,7 +391,7 @@ def profit_plot(
     df = pd.concat(df).reset_index(drop=True)
     fig = sns.lineplot(
         x="cum_prop", y="cum_profit", data=df, hue=group, marker=marker, **kwargs
-    ).legend(title=None)
+    )
     fig.set(ylabel="Profit", xlabel="Proportion of customers")
     fig.axhline(1, linestyle="--", linewidth=1)
     if contact:
@@ -402,6 +404,9 @@ def profit_plot(
             fig.axvline(l, linestyle="--", linewidth=1)
             for l in filter(lambda x: x < 1, cnf)
         ]
+    if len(dct) > 1 or len(pred) > 1:
+        fig.legend(title=None)
+
     return fig
 
 
@@ -453,12 +458,14 @@ def ROME_plot(df, rvar, lev, pred, qnt=10, cost=1, margin=2, marker="o", **kwarg
     rd = pd.concat(rd).reset_index(drop=True)
     fig = sns.lineplot(
         x="cum_prop", y="ROME", data=rd, hue=group, marker=marker, **kwargs
-    ).legend(title=None)
+    )
     fig.set(
         ylabel="Return on Marketing Expenditures (ROME)",
         xlabel="Proportion of customers",
     )
     fig.axhline(0, linestyle="--", linewidth=1)
+    if len(dct) > 1 or len(pred) > 1:
+        fig.legend(title=None)
     return fig
 
 
@@ -510,9 +517,11 @@ def gains_plot(df, rvar, lev, pred, qnt=10, marker="o", **kwargs):
     rd = pd.concat(rd).reset_index(drop=True)
     fig = sns.lineplot(
         x="cum_prop", y="cum_gains", data=rd, hue=group, marker=marker, **kwargs
-    ).legend(title=None)
+    )
     fig.set(ylabel="Cumulative gains", xlabel="Proportion of customers")
     plt.plot([0, 1], [0, 1], linestyle="--", linewidth=1)
+    if len(dct) > 1 or len(pred) > 1:
+        fig.legend(title=None)
     return fig
 
 
@@ -528,7 +537,7 @@ def lift_plot(df, rvar, lev, pred, qnt=10, marker="o", **kwargs):
     lev : str
         Name of the 'success' level in rvar
     pred : str
-        Name of the column in df with model predictions
+        Name, or list, of the column(s) in df with model predictions
     qnt : int
         Number of quantiles to create
     cost : int
@@ -564,9 +573,11 @@ def lift_plot(df, rvar, lev, pred, qnt=10, marker="o", **kwargs):
     rd = pd.concat(rd).reset_index(drop=True)
     fig = sns.lineplot(
         x="cum_prop", y="cum_lift", data=rd, hue=group, marker=marker, **kwargs
-    ).legend(title=None)
-    fig.axhline(1, linestyle="--", linewidth=1)
+    )
     fig.set(ylabel="Cumulative lift", xlabel="Proportion of customers")
+    fig.axhline(1, linestyle="--", linewidth=1)
+    if len(dct) > 1 or len(pred) > 1:
+        fig.legend(title=None)
     return fig
 
 
@@ -636,7 +647,7 @@ def evalbin(df, rvar, lev, pred, cost=1, margin=2, dec=3):
     result = pd.DataFrame()
     for key, val in dct.items():
         for p in pred:
-            result = result.append(calculate_metrics(key, val, p))
+            result = pd.concat([result, calculate_metrics(key, val, p)], axis=0)
 
     result.index = range(result.shape[0])
     result["index"] = result.groupby("Type").profit.transform(lambda x: x / x.max())
